with_layout_style

Attribute Macro with_layout_style 

#[with_layout_style]
Adds layout style fields and helpers to a props struct.

Use this on named-field props structs for components that should accept layout props such as width, height, margin, offset, gap, direction, and justification.